<!DOCTYPE html>
<html lang="en">
<head>
    <title>Bolinette</title>
</head>
<body>
    <h1>{{ response['code'] }} {{ response['status'] }}</h1>
    <ul>
        {% for key, value in response['data'].items() %}
        <li>{{ key }}: {{ value }}</li>
        {% endfor %}
    </ul>
</body>
</html>
